import type { PageServerLoad } from './$types';
import { API_URL } from '$env/static/private';
import type { Chapter, Puzzle } from '$lib/types';

export const load = (async ({ parent, fetch, cookies }) => {
	await parent();

	const session = cookies.get('session');

	const res = await fetch(`${API_URL}/chapters`, {
		headers: {
			Authorization: `Bearer ${session}`
		}
	});

	if (!res.ok) {
		return {
			chapters: []
		};
	}

	const chapters = (await res.json()) as Chapter[];

	for (const chapter of chapters) {
		chapter.puzzles = [];

		const res = await fetch(`${API_URL}/chapter/${chapter.id}`, {
			headers: {
				Authorization: `Bearer ${session}`
			}
		});

		if (!res.ok) continue;

		let { puzzles } = (await res.json()) as { puzzles: Puzzle[] };

		puzzles = puzzles.sort((a, b) => a.scoreMax - b.scoreMax);

		chapter.puzzles = puzzles;
	}

	return {
		chapters
	};
}) satisfies PageServerLoad;
